<?php
/*
Plugin Name: Optin Fire
plugin URI: http://www.99robots.com/optin-fire
Description: The Optin plugin for WordPress allows you to add a highly customizable and targeted optin fire to any page of your website.
version: 1.1.5
Author: 99 Robots
Author URI: http://www.99robots.com
License: GPL2
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Global Definitions
 */

// Item Name

if (!defined('NNROBOTS_OPTIN_FIRE_ITEM_NAME'))
    define('NNROBOTS_OPTIN_FIRE_ITEM_NAME', 'Optin Fire');

// Store URL

if (!defined('NNROBOTS_OPTIN_FIRE_STORE_URL'))
    define('NNROBOTS_OPTIN_FIRE_STORE_URL', 'https://99robots.com');

// Minimum PHP Version

if (!defined('NNROBOTS_OPTIN_FIRE_MIN_PHP_VERSION'))
    define('NNROBOTS_OPTIN_FIRE_MIN_PHP_VERSION', '5.4.0');

// Plugin Name

if (!defined('NNROBOTS_OPTIN_FIRE_PLUGIN_NAME'))
    define('NNROBOTS_OPTIN_FIRE_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));

// Plugin directory

if (!defined('NNROBOTS_OPTIN_FIRE_PLUGIN_DIR'))
    define('NNROBOTS_OPTIN_FIRE_PLUGIN_DIR', plugin_dir_path(__FILE__) );

// Plugin url

if (!defined('NNROBOTS_OPTIN_FIRE_PLUGIN_URL'))
    define('NNROBOTS_OPTIN_FIRE_PLUGIN_URL', plugins_url() . '/' . NNROBOTS_OPTIN_FIRE_PLUGIN_NAME);

// Plugin verison

if (!defined('NNROBOTS_OPTIN_FIRE_VERSION_NUM'))
    define('NNROBOTS_OPTIN_FIRE_VERSION_NUM', '1.1.5');

// Date Format

if (!defined('NNROBOTS_OPTIN_FIRE_DATE_FORMAT'))
    define('NNROBOTS_OPTIN_FIRE_DATE_FORMAT', 'Y-m-d');

// Entry Date Format

if (!defined('NNROBOTS_OPTIN_FIRE_ENTRY_DATE_FORMAT'))
    define('NNROBOTS_OPTIN_FIRE_ENTRY_DATE_FORMAT', 'Y-m-d H:i:s');

// Set default timezone

date_default_timezone_set(timezone_name_from_abbr(null, (int) get_option('gmt_offset') * 3600 , true));

/**
 * Activatation / Deactivation
 */

register_activation_hook( __FILE__, 	array('NNRobots_Optin_Fire', 'register_activation'));

/**
 * Hooks / Filter
 */

add_action('admin_menu', 				array('NNRobots_Optin_Fire', 'menu'));
add_action('init', 						array('NNRobots_Optin_Fire', 'load_textdoamin'));

// Admin Notices
add_action( 'admin_notices', 			array('NNRobots_Optin_Fire', 'admin_notices'));

// Model

include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'core/model/stats.php');
include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'core/model/email-signups.php');
include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "core/model/email-entries.php");

// Functions

include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/functions.php');
include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'core/functions.php');

// Widget

include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "widget.php");

// Shortcode

include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "shortcode.php");

// Software Licensing Updates

add_action('wp_ajax_nnr_of_license_action', array('NNRobots_Optin_Fire', 'license_action'));

if ( !class_exists('EDD_SL_Plugin_Updater') ) {
	include_once( dirname( __FILE__ ) . '/admin/includes/edd-software-licensing-updates/EDD_SL_Plugin_Updater.php' );
}

$edd_updater = new EDD_SL_Plugin_Updater( NNROBOTS_OPTIN_FIRE_STORE_URL , __FILE__, array(
		'version' 	=> NNROBOTS_OPTIN_FIRE_VERSION_NUM,
		'license' 	=> NNRobots_Optin_Fire::get_license_key(),
		'item_name' => NNROBOTS_OPTIN_FIRE_ITEM_NAME,
		'author' 	=> '99 Robots',
	)
);

/**
 *
 * Main class used to display the optin fire on the website and display backend options
 *
 * @since 1.0.0
 */
class NNRobots_Optin_Fire {

	/**
	 * prefix
	 *
	 * (default value: 'nnrobots_optin_fire_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $prefix = 'nnrobots_optin_fire_';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnr-of-')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $prefix_dash = 'nnr-of-';

	/**
	 * text_domain
	 *
	 * (default value: 'nnrobots-optin-fire')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	public static $text_domain = 'nnrobots-optin-fire';

	/**
	 * dashboard_page
	 *
	 * (default value: "nnrobots-optin-fire-admin")
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	public static $dashboard_page = "nnrobots-optin-fire-admin";

	/**
	 * add_new_page
	 *
	 * (default value: "nnrobots-new-optin-fire")
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	public static $add_new_page = "nnrobots-new-optin-fire";

	/**
	 * stats_page
	 *
	 * (default value: 'nnrobots-optin-fire-stats')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $stats_page = 'nnrobots-optin-fire-stats';

	/**
	 * emails_page
	 *
	 * (default value: 'nnrobots-optin-fire-emails')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $emails_page = 'nnrobots-optin-fire-emails';

	/**
	 * entries_page
	 *
	 * (default value: 'nnrobots-optin-fire-entries')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $entries_page = 'nnrobots-optin-fire-entries';

	/**
	 * updates_page
	 *
	 * (default value: 'nnrobots-optin-fire-updates')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $updates_page = 'nnrobots-optin-fire-updates';

	/**
	 * import_export_page
	 *
	 * (default value: 'nnrobots-optin-fire-import-export')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $import_export_page = 'nnrobots-optin-fire-import-export';

	/**
	 * aweber_app_id
	 *
	 * (default value: '343d929f')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	public static $aweber_app_id = '343d929f';

	/**
	 * social_icons
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $social_icons = array(
		'fa-delicious' 		=> 'Delicious',
		'fa-digg' 			=> 'Digg',
		'fa-dribbble' 		=> 'Dribbble',
		'fa-facebook' 		=> 'Facebook',
		'fa-flickr' 		=> 'Flickr',
		'fa-foursquare' 	=> 'Four Square',
		'fa-github' 		=> 'Github',
		'fa-google-plus'	=> 'Google+',
		'fa-linkedin' 		=> 'LinkedIn',
		'fa-instagram'		=> 'Instagram',
		'fa-pinterest' 		=> 'Pinterest',
		'fa-reddit' 		=> 'Reddit',
		'fa-tumblr' 		=> 'Tumblr',
		'fa-twitch' 		=> 'Twitch',
		'fa-twitter' 		=> 'Twitter',
		'fa-vine' 			=> 'Vine',
		'fa-yelp' 			=> 'Yelp',
		'fa-youtube' 		=> 'YouTube',
	);

	/**
	 * font_families
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $font_families = array(
		'initial',
		'inherit',
		'Georgia, serif',
		'"Palatino Linotype", "Book Antiqua", Palatino, serif',
		'"Times New Roman", Times, serif',
		'Arial, Helvetica, sans-serif',
		'"Arial Black", Gadget, sans-serif',
		'"Comic Sans MS", cursive, sans-serif',
		'Impact, Charcoal, sans-serif',
		'"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		'Tahoma, Geneva, sans-serif',
		'"Trebuchet MS", Helvetica, sans-serif',
		'Verdana, Geneva, sans-serif',
		'"Courier New", Courier, monospace',
		'"Lucida Console", Monaco, monospace',
	);

	/**
	 * template_order
	 *
	 * (default value: array(1, 2, 3, 4, 5, 6, 7 ,8))
	 *
	 * @var array
	 * @access public
	 * @static
	 */
	static $template_order = array(1, 2, 3, 4, 5, 6, 7);

	/**
	 * template_names
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $template_names = array(
		'',
		'Call To Action',
		'Image and Call To Action #1',
		'Image and Call To Action #2',
		'Image and Call To Action #3',
		'Image and Call To Action #4',
		'Image, List and Call To Action #1',
		'Image, List and Call To Action #2',
	);

	/**
	 * template_descriptions
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $template_descriptions = array(
		'',
		'Call To Action',
		'Image and Call To Action #1',
		'Image and Call To Action #2',
		'Image and Call To Action #3',
		'Image and Call To Action #4',
		'Image, List and Call To Action #1',
		'Image, List and Call To Action #2',
	);

	/**
	 * effects
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $effects = array(
		'blind',
		'bounce',
		'clip',
		'drop',
		'explode',
		'fade',
		'fold',
		'highlight',
		'pulsate',
		'scale',
		'shake',
		'size',
		'slide',
	);

	/**
	 * newsletter_templates
	 *
	 * (default value: array('1', '2', '3', '4', '5', '6', '7'))
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $newsletter_templates = array('1', '2', '3', '4', '5', '6', '7');

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdoamin() {
		load_plugin_textdomain(self::$text_domain, false, basename( dirname( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Performs tasks needed upon activation
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/activation.php');

	}

	/**
	 * Display an admin notice message to users.
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function admin_notices() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/admin-notices.php');

	}

	/**
	 * Perform all the actions with a license
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function license_action() {

		if ( !isset($_POST['license_key']) ) {
			echo '';
			die();
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> $_POST['license_action'],
			'license' 		=> $_POST['license_key'],
			'item_name' 	=> urlencode( NNROBOTS_OPTIN_FIRE_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_OPTIN_FIRE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			echo $response;
			die();
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		if ( $_POST['license_action'] == 'activate_license' ) {
			self::update_license_key($_POST['license_key']);
		} else if ( $_POST['license_action'] == 'deactivate_license' && $license_data->license == 'deactivated') {
			self::update_license_key('');
		}

		// decode the license data

		echo $license_data->license;

		die();

	}

	/**
	 * Check if license key is active
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function is_license_active( $license_key ) {

		if ( !isset( $license_key ) ) {
			return false;
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> 'check_license',
			'license' 		=> $license_key,
			'item_name' 	=> urlencode( NNROBOTS_OPTIN_FIRE_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_OPTIN_FIRE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// decode the license data

		if ( isset($license_data->license) && $license_data->license == 'valid' ) {
			return true;
		} else {
			return false;
		}

	}

	/**
	 * Get the license key
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function get_license_key() {

		// Get the license key from based on WordPress install

		if ( function_exists('is_multisite') && is_multisite() ) {
			$license_key = get_site_option(self::$prefix . 'license_key');
		} else {
			$license_key = get_option(self::$prefix . 'license_key');
		}

		// Check if license key is set

		if ( $license_key === false ) {
			$license_key = '';
		}

		return $license_key;
	}

	/**
	 * Update the license key
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function update_license_key($license_key) {

		if ( isset( $license_key ) ) {

			// Get the license key from based on WordPress install

			if ( function_exists('is_multisite') && is_multisite() ) {

				update_site_option(self::$prefix . 'license_key', $license_key);

			} else {

				update_option(self::$prefix . 'license_key', $license_key);

			}

		}

	}

	/**
	 * Hooks for the admin menu and submenus
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function menu() {
	 	add_menu_page(
	 		__("Optin Fire" , self::$text_domain),
	 		__("Optin Fire" , self::$text_domain),
	 		'manage_options',
	 		self::$dashboard_page,
	 		array('NNRobots_Optin_Fire','dashboard'),
	    	plugin_dir_url(__FILE__) . 'img/logo.png" style="width:20px;padding-top: 6px;');

		$dashboard_page_load = add_submenu_page(
			self::$dashboard_page,
			__("All Optins" , self::$text_domain),
			__("All Optins" , self::$text_domain),
			'manage_options',
			self::$dashboard_page,
			array('NNRobots_Optin_Fire','dashboard'));
		add_action("admin_print_scripts-$dashboard_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_dashboard'));

		$add_new_page_load = add_submenu_page(
			null, //self::$dashboard_page,
			__("Add New" , self::$text_domain),
			__("Add New" , self::$text_domain),
			'manage_options',
			self::$add_new_page,
			array('NNRobots_Optin_Fire','add_edit'));
		add_action("admin_print_scripts-$add_new_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_add_edit'));

		$stats_page_load = add_submenu_page(
			self::$dashboard_page,
			__("Stats" , self::$text_domain),
			__("Stats" , self::$text_domain),
			'manage_options',
			self::$stats_page,
			array('NNRobots_Optin_Fire','stats'));
		add_action("admin_print_scripts-$stats_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_stats'));

		$emails_page_load = add_submenu_page(
			self::$dashboard_page,
			__("Email List" , self::$text_domain),
			__("Email List" , self::$text_domain),
			'manage_options',
			self::$emails_page,
			array('NNRobots_Optin_Fire','emails'));
		add_action("admin_print_scripts-$emails_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_emails'));

		$entries_page_load = add_submenu_page(
			self::$dashboard_page,
			__("Entries" , self::$text_domain),
			__("Entries" , self::$text_domain),
			'manage_options',
			self::$entries_page,
			array('NNRobots_Optin_Fire','entries'));
		add_action("admin_print_scripts-$entries_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_entries'));

		$import_export_page_load = add_submenu_page(
			self::$dashboard_page,
			__("Import / Export" , self::$text_domain),
			__("Import / Export" , self::$text_domain),
			'manage_options',
			self::$import_export_page,
			array('NNRobots_Optin_Fire','import_export'));
		add_action("admin_print_scripts-$import_export_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_import_export'));

		$updates_page_load = add_submenu_page(
			self::$dashboard_page,
			__("Updates" , self::$text_domain),
			__("Updates" , self::$text_domain),
			'manage_options',
			self::$updates_page,
			array('NNRobots_Optin_Fire','updates'));
		add_action("admin_print_scripts-$updates_page_load", array('NNRobots_Optin_Fire', 'inline_admin_scripts_updates'));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_dashboard() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_sortable_css',			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-sortable.css');
	    wp_enqueue_style('wp-color-picker');

	    // Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_sortable_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-sortable.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_moment_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/moment.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'admin_js', 						NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/dashboard.js', array('wp-color-picker', 'jquery'), false, true );
		wp_localize_script(self::$prefix . 'admin_js', 'nnr_of_dashboard_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
		));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_add_edit() {

	    // Styles

	    wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_vertical_tabs_css',		NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap.vertical-tabs.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_slider_css', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-slider.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_datetimepicker_css', 	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-datetimepicker.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_iconpicker_css', 		NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-iconpicker.min.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_formhelpers_css', 		NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-formhelpers.min.css');
		wp_enqueue_style(self::$prefix . 'selectize_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/includes/selectize/css/selectize.bootstrap3.css');

	    // Scripts

		wp_enqueue_media();
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_slider_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-slider.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_moment_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/moment.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_datetimepicker_js', 	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-datetimepicker.min.js', array('jquery', self::$prefix . 'bootstrap_moment_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_iconset_js',NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/iconset-fontawesome-4.2.0.min.js', array('jquery', self::$prefix . 'bootstrap_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_iconpicker_js', 		NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-iconpicker.js', array('jquery', self::$prefix . 'bootstrap_js', self::$prefix . 'bootstrap_iconpicker_iconset_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_formhelpers_js', 		NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-formhelpers.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'selectize_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/includes/selectize/js/standalone/selectize.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'google_font_js',					NNROBOTS_OPTIN_FIRE_PLUGIN_URL .  '/core/js/webfontloader.js');

	    wp_enqueue_style('wp-color-picker');
	    wp_enqueue_script(self::$prefix . 'admin_add_edit_js',				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/add-edit.js', array('wp-color-picker', 'jquery', 'jquery-ui-tabs', 'jquery-ui-datepicker'), false, true);

	    wp_enqueue_script(self::$prefix . 'email_accounts_js', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/email-accounts.js');
		wp_localize_script(self::$prefix . 'email_accounts_js', 'nnr_of_email_accounts_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
		));

	    wp_enqueue_script(self::$prefix . 'repeater_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/repeater.js', array('jquery', 'jquery-ui-sortable'));
		wp_localize_script(self::$prefix . 'repeater_js', 'nnr_of_repeater_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'social_icons'		=> self::$social_icons,
			'remove'			=> __('Remove', self::$text_domain),
		));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_stats() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_datetimepicker_css',	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-datetimepicker.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_sortable_css',			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-sortable.css');

	    wp_dequeue_style('revisions');

	    // Scripts

	    wp_enqueue_script(self::$prefix . 'line_graph_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/Chart.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_sortable_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-sortable.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_moment_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/moment.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_datetimepicker_js', 	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-datetimepicker.min.js', array('jquery', self::$prefix . 'bootstrap_moment_js'));

	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_emails() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_datetimepicker_css', 	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-datetimepicker.min.css');
	     wp_enqueue_style(self::$prefix . 'bootstrap_sortable_css',			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-sortable.css');

		// Scripts

		wp_enqueue_script(self::$prefix . 'line_graph_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/Chart.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_moment_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/moment.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_datetimepicker_js', 	NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-datetimepicker.min.js', array('jquery', self::$prefix . 'bootstrap_moment_js'));
		wp_enqueue_script(self::$prefix . 'bootstrap_sortable_js', 			NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-sortable.js', array('jquery'));
	    wp_enqueue_script(self::$prefix . 'email_js', 						NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/email.js', array('jquery'));
	    wp_localize_script(self::$prefix . 'email_js', 'nnr_of_emails_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'today'				=> date('m/d/Y'),
		));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_entries() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 								NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 							NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 								NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_datetimepicker_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/bootstrap-datetimepicker.min.css');

	    // Scripts

		wp_enqueue_script(self::$prefix . 'line_graph_js', 								NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/Chart.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 								NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_moment_js', 						NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/moment.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'bootstrap_datetimepicker_js', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap-datetimepicker.min.js', array('jquery', self::$prefix . 'bootstrap_moment_js'));
	    wp_enqueue_script(self::$prefix . 'entries_js', 								NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/entries.js', array('jquery'));
	    wp_localize_script(self::$prefix . 'entries_js', 'nnr_of_entries_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'today'				=> date('m/d/Y')
		));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_import_export() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');

	    // Scripts

		wp_enqueue_script(self::$prefix . 'bootstrap_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/bootstrap.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'import_export_js', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/import-export.js', array('jquery'));
		wp_localize_script(self::$prefix . 'import_export_js', 'nnr_of_import_export_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
		));
	}

	/**
	 * Hooks to "admin_print_scripts-$page"
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function inline_admin_scripts_updates() {

		wp_enqueue_style(self::$prefix . 'settings_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/settings.css');
	    wp_enqueue_style(self::$prefix . 'fontawesome_css', 				NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/fonts/font-awesome.min.css');
	    wp_enqueue_style(self::$prefix . 'bootstrap_css', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');

	    wp_enqueue_script(self::$prefix . 'updates_js', 					NNROBOTS_OPTIN_FIRE_PLUGIN_URL . '/admin/js/updates.js', array('jquery'));
	    wp_localize_script(self::$prefix . 'updates_js', 'nnr_of_updates_data', array(
			'prefix_dash' 		=> self::$prefix_dash,
			'activate_text'		=> __('Activate', self::$text_domain),
			'deactivate_text'	=> __('Deactivate', self::$text_domain),
			'no_license_key'		=> __('Please add or activate your License Key to get automatic updates.  Without a valid license key you will not receive regular updates. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'expired'				=> __('EXPIRED: This license key has expired.  Please renew your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'activation_error'		=> __('INVALID LICENSE KEY: The license key is not valid please try again. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>.',
			'activation_valid'		=> __('SUCCESS: Your license key is valid.', self::$text_domain),
			'deactivation_valid'	=> __('SUCCESS: This site has been deactivated.', self::$text_domain),
			'deactivation_error'	=> __('DEACTIVATION FAILED: This site could not be deactivated.', self::$text_domain),
		));
	}

	/**
	 * Function called when user loads All Optin submenu
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function dashboard() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/controllers/dashboard.php');

	}

	/**
	 * Function called when user loads New Optin submenu
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_edit() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/controllers/add-edit.php');

	}

	/**
	 * Displays content for the Stats page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function stats() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/controllers/stats.php');

	}

	/**
	 * Dsiplay the Content of the Emails page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function emails() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . 'admin/controllers/emails.php');

	}

	/**
	 * Dsiplays the content for the Entries page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function entries() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "admin/controllers/entries.php");

	}

	/**
	 * Dsiplays the content for the Import / Export page
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function import_export() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "admin/controllers/import-export.php");

	}

	/**
	 * Display the Updates of the update pages
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function updates() {

		include_once(NNROBOTS_OPTIN_FIRE_PLUGIN_DIR . "admin/controllers/updates.php");

	}
}
?>